@@ -116,11 +116,16 @@ def is_classic_task(tup):
     Takes (name, object) tuple, returns True if it's a non-Fab public callable.
     """
     name, func = tup
-    return (
-        callable(func)
-        and (func not in _internals)
-        and not name.startswith('_')
-    )
+    try:
+        is_classic = (
+            callable(func)
+            and (func not in _internals)
+            and not name.startswith('_')
+        )
+    # Handle poorly behaved __eq__ implementations
+    except (ValueError, TypeError):
+        is_classic = False
+    return is_classic
 
 
 def load_fabfile(path, importer=None):
@@ -348,7 +353,10 @@ def _crawl(name, mapping):
 
 def crawl(name, mapping):
     try:
-        return _crawl(name, mapping)
+        result = _crawl(name, mapping)
+        # Handle module-not-task (i.e. "fab foo" where "foo" is a task module,
+        # not a task.)
+        return result if callable(result) else None
     except (KeyError, TypeError):
         return None
 
@@ -492,8 +500,9 @@ def parse_arguments(arguments):
         if ':' in cmd:
             cmd, argstr = cmd.split(':', 1)
             for pair in _escape_split(',', argstr):
-                k, _, v = pair.partition('=')
-                if _:
+                result = _escape_split('=', pair)
+                if len(result) > 1:
+                    k, v = result
                     # Catch, interpret host/hosts/role/roles/exclude_hosts
                     # kwargs
                     if k in ['host', 'hosts', 'role', 'roles', 'exclude_hosts']:
@@ -511,7 +520,7 @@ def parse_arguments(arguments):
                     else:
                         kwargs[k] = v
                 else:
-                    args.append(k)
+                    args.append(result[0])
         cmds.append((cmd, args, kwargs, hosts, roles, exclude_hosts))
     return cmds
 
